<?php
/*
Plugin Name: Admin Bar Minimiser
Plugin URI: http://www.presscoders.com/plugins/admin-bar-minimiser/
Description: Easy way to minimise the new WordPress 3.1 admin bar at the click of a button. Make it appear again just as easily!
Version: 1.1
Author: David Gwyer
Author URI: http://www.presscoders.com
*/

/*  Copyright 2009 David Gwyer (email : d.v.gwyer@presscoders.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*if ( version_compare($wp_version, "3.1", "<" ) ) {
	exit("'Admin Bar Minimiser' Plugin requires WordPress 3.1 or higher to work properly!");
}*/

// Note: jq_min prefix is derived from [jq]uery [min]imiser
define("JQ_MIN", WP_PLUGIN_URL.'/'.plugin_basename(dirname(__FILE__)));

// Plugin hooks/filters
add_action( 'init', 'jq_min_init' );
add_action( 'admin_menu', 'jq_min_add_options_page' );
add_action( 'admin_init', 'jq_min_admin_init' );
register_activation_hook( __FILE__, 'jq_min_add_defaults' );
register_uninstall_hook( __FILE__, 'jq_min_delete_plugin_options' );
add_filter( 'plugin_action_links', 'jq_min_plugin_action_links', 10, 2 );

// Register the blog scripts
function jq_min_init(){

	// Only attempt to minimise admin bar if it is enabled
	if ( is_admin_bar_showing() ) {

		// Register scripts
		wp_register_script('jq_min', JQ_MIN.'/js/minimise_admin_bar.js', array('jquery'));

		// Enqueue them
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'jq_min' );

		// Add these actions only if admin bar is enabled
		add_action('wp_head', 'jq_min_add_css');
		add_action('admin_head', 'jq_min_add_admin_css');
	}
}

function jq_min_admin_init(){
	register_setting( 'jq_min_plugin_options', 'jq_min_options' );
}

// Add a little front end CSS and jQuery
function jq_min_add_css() {
	$options = get_option('jq_min_options');
	$maximised = $options['chk_front_end'];
	if ( $maximised != '1' ) {
		echo "<style type=\"text/css\">#wpadminbar { top: -28px; } #adminbar-padding { padding-top: 0px !important; }</style>\r\n";
	}
	else {
		echo "<script type=\"text/javascript\">jQuery(document).ready(function($) { $(\"#adminbar_tab\").text(\"Hide\"); });</script>";
	}

	echo "<style type=\"text/css\">div#adminbar_tab { clear:both;text-align:center;background:transparent;width:38px;position: relative;top:0px;color:#000;font-size:12px;font-style:italic;background: #aaa;opacity:0.2;padding:4px;cursor:pointer; } div#adminbar_tab:hover {opacity:0.7;} </style>";
}

// Add a little admin css - opacity set to zero for admin bar tab as it displays better
function jq_min_add_admin_css() {
	$options = get_option('jq_min_options');
	$maximised = $options['chk_wpadmin'];

	if ( $maximised != '1' ) {
		echo "<style type=\"text/css\">#wpadminbar { top: -28px; } #adminbar-padding { padding-top: 0px !important; }</style>\r\n";
	}
	else {
		echo "<script type=\"text/javascript\">jQuery(document).ready(function($) { $(\"#adminbar_tab\").text(\"Hide\"); });</script>";
	}

	echo "<style type=\"text/css\">div#adminbar_tab { clear:both;text-align:center;background:transparent;width:38px;position: relative;top:0px;color:#000;font-size:12px;font-style:italic;background: #aaa;opacity:0;padding:4px;cursor:pointer; } div#adminbar_tab:hover {opacity:0.7;} </style>";
}

// Delete options table entries ONLY when plugin deactivated AND deleted
function jq_min_delete_plugin_options() {
	delete_option('jq_min_options');
}

// Define default option settings
function jq_min_add_defaults() {
	$tmp = get_option('jq_min_options');
    if( !$tmp ) {
		// if no options present set-up defaults
		$arr = array("chk_wpadmin" => "0", "chk_front_end" => "0");
		update_option('jq_min_options', $arr);
	}
}

// Add admin menu page
function jq_min_add_options_page() {
	add_options_page('Admin Bar Minimiser Options Page', 'Admin Bar Minimiser', 'manage_options', __FILE__, 'jq_min_render_form');
}

// Draw the menu page itself
function jq_min_render_form() {
	?>
	<div class="wrap">
		<div class="icon32" id="icon-options-general"><br></div>
		<h2>Admin Bar Minimiser</h2>
		<p style="float: left;">Configure the WordPress 3.1 admin bar options below.</p>
		<p style="float: right;"><form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="6S23EDELXPM7L">
<input type="image" src="https://www.paypal.com/en_US/GB/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online.">
<img alt="" border="0" src="https://www.paypal.com/en_GB/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
		<form method="post" action="options.php">
			<?php settings_fields('jq_min_plugin_options'); ?>
			<?php $options = get_option('jq_min_options'); ?>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">Front end settings</th>
					<td>
						<label><input name="jq_min_options[chk_front_end]" type="checkbox" value="1" <?php checked('1', $options['chk_front_end']); ?> /> Maximise by default</label>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row">Admin settings</th>
					<td>
						<label><input name="jq_min_options[chk_wpadmin]" type="checkbox" value="1" <?php checked('1', $options['chk_wpadmin']); ?> /> Maximise by default</label>
					</td>
				</tr>
			</table>
			<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" /></p>
		</form>
	</div>
	<?php	
}

// Display a Settings link on the main Plugins page
function jq_min_plugin_action_links( $links, $file ) {

	if ( $file == plugin_basename( __FILE__ ) ) {
		$jq_min_links = '<a href="'.get_admin_url().'options-general.php?page=admin-bar-minimiser/admin-bar-minimiser.php">'.__('Settings').'</a>';
	}

	// make the 'Settings' link appear first
	array_unshift( $links, $jq_min_links );

	return $links;
}
